@@ -39,8 +39,8 @@ PIRTabsChoiceDialog::PIRTabsChoiceDialog(
   ui->tabsChoiceListWidget->addItem(
     new PIRTabsWidgetItem("Macro Panels", Macro_Tabs));
 
-  ui->tabsChoiceListWidget->addItem(
-    new PIRTabsWidgetItem("Keyset Search Panels", PowerSearch_Tabs));
+//  ui->tabsChoiceListWidget->addItem(
+//    new PIRTabsWidgetItem("Keyset Search Panels", PowerSearch_Tabs));
 
   ui->tabsChoiceListWidget->addItem(
     new PIRTabsWidgetItem("Advanced Settings", Advanced_Tabs));
