@@ -50,6 +50,53 @@ void CreativeAudio1::populateProtocol(
 }
 
 
+CreativeAudioEx::CreativeAudioEx(
+  unsigned int index)
+  : PIRKeysetMetaData(
+      "Speakers 2 (experimental)",
+      Creative_Make,
+      index)
+{
+}
+
+
+void CreativeAudioEx::populateProtocol(
+  QObject *guiObject)
+{
+  if (threadableProtocol)
+  {
+    // Keyset already populated.
+    return;
+  }
+
+  threadableProtocol = new NECProtocol(guiObject, index, true, false);
+
+  setPreData(0x44C1, 16);
+
+  addKey("Input Select", Input_Key, 0x37, 8);
+  addKey("vol up", VolumeUp_Key, 0x47, 8);
+  addKey("Dynamic Mode Toggle", Red_Key, 0x4F, 8); // hack
+  addKey("mute", Mute_Key, 0x77, 8);
+  addKey("power", Power_Key, 0x87, 8);
+  addKey("Dolby", NoiseReduction_Key, 0xA7, 8);
+  addKey("Dolby", Blue_Key, 0xA7, 8); // hack
+  addKey("vol down", VolumeDown_Key, 0xC7, 8);
+  addKey("Analog on/off", Green_Key, 0xD7, 8); // hack
+  addKey("Effect Select", Yellow_Key, 0xF2, 8); // hack
+
+  addKey("rear_center", Unmapped_Key, 0x17, 8);
+  addKey("center", Unmapped_Key, 0x97, 8);
+  addKey("test", Unmapped_Key, 0xF7, 8);
+  addKey("rear", Unmapped_Key, 0xE7, 8);
+  addKey("subwoofer", Unmapped_Key, 0x67, 8);
+  addKey("coaxial", Unmapped_Key, 0x27, 8);
+  addKey("optical", Unmapped_Key, 0x0F, 8);
+  addKey("stereo", Unmapped_Key, 0x2F, 8);
+  addKey("dolby_digital_ex", Unmapped_Key, 0xCF, 8);
+  addKey("ned_6", Unmapped_Key, 0xB7, 8);
+}
+
+
 CreativeAudio2::CreativeAudio2(
   unsigned int index)
   : PIRKeysetMetaData(
