@@ -15,6 +15,16 @@ public:
     QObject *guiObject);
 };
 
+class CreativeAudioEx: public PIRKeysetMetaData
+{
+public:
+  CreativeAudioEx(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
 class CreativeAudio2: public PIRKeysetMetaData
 {
 public:
