@@ -65,6 +65,26 @@ public:
     QObject *guiObject);
 };
 
+class PanasonicTV2: public PIRKeysetMetaData
+{
+public:
+  PanasonicTV2(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
+class PanasonicTV2a: public PanasonicTV2
+{
+public:
+  PanasonicTV2a(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
 class PanasonicVCR1: public PIRKeysetMetaData
 {
 public:
@@ -105,6 +125,16 @@ public:
     QObject *guiObject);
 };
 
+class PanasonicVCR2: public PIRKeysetMetaData
+{
+public:
+  PanasonicVCR2(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
 class PanasonicDVD1: public PIRKeysetMetaData
 {
 public:
@@ -155,6 +185,16 @@ public:
     QObject *guiObject);
 };
 
+class PanasonicAudio3: public PIRKeysetMetaData
+{
+public:
+  PanasonicAudio3(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
 class PanasonicAC1: public PIRKeysetMetaData
 {
 public:
