@@ -2,6 +2,7 @@
 #include "protocols/samsungprotocol.h"
 #include "protocols/lircprotocol.h"
 #include "protocols/rc5protocol.h"
+#include "protocols/samsungacprotocol.h"
 
 SamsungTV1::SamsungTV1(
   unsigned int index)
@@ -892,11 +893,10 @@ void SamsungAC1::populateProtocol(
 }
 
 
-/*
 SamsungAC2::SamsungAC2(
   unsigned int index)
-  : PIRKeysetMetaData(
-      "AC Keyset 2",
+  : PIRACKeyset(
+      "Air Conditioner 2",
       Samsung_Make,
       index)
 {
@@ -912,50 +912,209 @@ void SamsungAC2::populateProtocol(
     return;
   }
 
-  threadableProtocol = new ACProtocol(guiObject, index);
+  threadableProtocol = new SamsungACProtocol(guiObject, index);
 
-  addKey("Power Off", PowerOff_Subkey, 0x0, 4);
-  addKey("Power On", PowerOn_Subkey, 0xC, 4);
+  setPreData(0x201, 12);
 
-  addKey("Cool Mode - Normal", CoolModeNormal_Subkey, 0x0, 3);
-  addKey("Cool Mode - Turbo", CoolModeTurbo_Subkey, 0x3, 3);
-  addKey("Cool Mode - Far", CoolModeFar_Subkey, 0x6, 3);
-
-  addKey("Deflector L/R Off", DeflectorLROff_Subkey, 0x1, 1);
-  addKey("Deflector L/R On", DeflectorLROn_Subkey, 0x0, 1);
-  addKey("Deflector U/D Off", DeflectorUDOff_Subkey, 0x1, 1);
-  addKey("Deflector U/D On", DeflectorUDOn_Subkey, 0x0, 1);
-
-  // Sixteen temperature settings; make this a straight-up variable?
-  // It may be that only 18-30 are supported.
-//  addKey("Temperature 16", Temp16_Subkey, 0x0, 8);
-//  addKey("Temperature 17", Temp16_Subkey, 0x1, 8);
-  addKey("Temperature 18", Temp16_Subkey, 0x2, 8);
-  addKey("Temperature 19", Temp16_Subkey, 0x3, 8);
-  addKey("Temperature 20", Temp16_Subkey, 0x4, 8);
-  addKey("Temperature 21", Temp16_Subkey, 0x5, 8);
-  addKey("Temperature 22", Temp16_Subkey, 0x6, 8);
-  addKey("Temperature 23", Temp16_Subkey, 0x7, 8);
-  addKey("Temperature 24", Temp16_Subkey, 0x8, 8);
-  addKey("Temperature 25", Temp16_Subkey, 0x9, 8);
-  addKey("Temperature 26", Temp16_Subkey, 0xA, 8);
-  addKey("Temperature 27", Temp16_Subkey, 0xB, 8);
-  addKey("Temperature 28", Temp16_Subkey, 0xC, 8);
-  addKey("Temperature 29", Temp16_Subkey, 0xD, 8);
-  addKey("Temperature 30", Temp16_Subkey, 0xE, 8);
-//  addKey("Temperature 31", Temp31_Subkey, 0xF, 8);
-
-  addKey("Fan - Auto", FanSpeedAuto_Subkey, 0x0, 3);
-  addKey("Fan - Low", FanSpeedLow_Subkey, 0x2, 3);
-  addKey("Fan - Medium", FanSpeedMed_Subkey, 0x4, 3);
-  addKey("Fan - High", FanSpeedHigh_Subkey, 0x6, 3);
-
-  addKey("Mode - auto", ModeAuto_Subkey, 0x0, 4);
-  addKey("Mode - cool", ModeCool_Subkey, 0x1, 4);
-  addKey("Mode - DeHumidify", ModeDehumidify_Subkey, 0x2, 4);
-  addKey("Mode - fan", ModeFan_Subkey, 0x03, 4);
+  // Bit of a hack:
+  addKey("Send Command", ACSendCommand_Key, 0x0, 0);
+  addKey("Set Timer", ACSetTimer_Key, 0x0, 0);
+}
+
+
+void SamsungAC2::getTurboModePairs(
+  PIRStatePairs &turboModePairs) const
+{
+  resetPairs(turboModePairs);
+
+  PIRStatePair *normalPair = new PIRStatePair(
+    "Normal", 0x21);
+  turboModePairs.push_back(normalPair);
+
+  PIRStatePair *turboPair = new PIRStatePair(
+    "Turbo", 0x27);
+  turboModePairs.push_back(turboPair);
+
+  PIRStatePair *farPair = new PIRStatePair(
+    "Far", 0x2D);
+  turboModePairs.push_back(farPair);
+}
+
+void SamsungAC2::getSwingPairs(
+  PIRStatePairs &swingPairs) const
+{
+  resetPairs(swingPairs);
+
+  PIRStatePair *swingOffPair = new PIRStatePair(
+    "Off", 0xFE);
+  swingPairs.push_back(swingOffPair);
+
+  PIRStatePair *swingUDPair = new PIRStatePair(
+    "Up/Down", 0xAE);
+  swingPairs.push_back(swingUDPair);
+
+  PIRStatePair *swingLRPair = new PIRStatePair(
+    "Left/Right", 0xBE);
+  swingPairs.push_back(swingLRPair);
+
+  PIRStatePair *swingUDLRPair = new PIRStatePair(
+    "U/D/L/R", 0xCE);
+  swingPairs.push_back(swingUDLRPair);
+}
+
+void SamsungAC2::getTemperaturePairs(
+  PIRStatePairs &temperaturePairs) const
+{
+  resetPairs(temperaturePairs);
+
+  PIRStatePair *eighteenPair = new PIRStatePair(
+    "18 C", 0x23);
+  temperaturePairs.push_back(eighteenPair);
+
+  PIRStatePair *nineteenPair = new PIRStatePair(
+    "19 C", 0x33);
+  temperaturePairs.push_back(nineteenPair);
+
+  PIRStatePair *twentyPair = new PIRStatePair(
+    "20 C", 0x43);
+  temperaturePairs.push_back(twentyPair);
+
+  PIRStatePair *twentyonePair = new PIRStatePair(
+    "21 C", 0x53);
+  temperaturePairs.push_back(twentyonePair);
+
+  PIRStatePair *twentytwoPair = new PIRStatePair(
+    "22 C", 0x63);
+  temperaturePairs.push_back(twentytwoPair);
+
+  PIRStatePair *twentythreePair = new PIRStatePair(
+    "23 C", 0x73);
+  temperaturePairs.push_back(twentythreePair);
+
+  PIRStatePair *twentyfourPair = new PIRStatePair(
+    "24 C", 0x83);
+  temperaturePairs.push_back(twentyfourPair);
+
+  PIRStatePair *twentyfivePair = new PIRStatePair(
+    "25 C", 0x93);
+  temperaturePairs.push_back(twentyfivePair);
+
+  PIRStatePair *twentysixPair = new PIRStatePair(
+    "26 C", 0xA3);
+  temperaturePairs.push_back(twentysixPair);
+
+  PIRStatePair *twentysevenPair = new PIRStatePair(
+    "27 C", 0xB3);
+  temperaturePairs.push_back(twentysevenPair);
+
+  PIRStatePair *twentyeightPair = new PIRStatePair(
+    "28 C", 0xC3);
+  temperaturePairs.push_back(twentyeightPair);
+
+  PIRStatePair *twentyninePair = new PIRStatePair(
+    "29 C", 0xD3);
+  temperaturePairs.push_back(twentyninePair);
+
+  PIRStatePair *thirtyPair = new PIRStatePair(
+    "30 C", 0xE3);
+  temperaturePairs.push_back(thirtyPair);
+}
+
+
+// Only 4 bits for the following!
+void SamsungAC2::getFanPairs(
+  PIRStatePairs &fanPairs) const
+{
+  resetPairs(fanPairs);
+
+  PIRStatePair *autoPair = new PIRStatePair(
+    "Auto", 0x1);
+  fanPairs.push_back(autoPair);
+
+  PIRStatePair *lowPair = new PIRStatePair(
+    "Low", 0x5);
+  fanPairs.push_back(lowPair);
+
+  PIRStatePair *mediumPair = new PIRStatePair(
+    "Medium", 0x9);
+  fanPairs.push_back(mediumPair);
+
+  PIRStatePair *highPair = new PIRStatePair(
+    "High", 0xB);
+  fanPairs.push_back(highPair);
+}
+
+
+void SamsungAC2::getModePairs(
+  PIRStatePairs &modePairs) const
+{
+  resetPairs(modePairs);
+
+  PIRStatePair *autoPair = new PIRStatePair(
+    "Auto", 0x0);
+  modePairs.push_back(autoPair);
+
+  PIRStatePair *coolPair = new PIRStatePair(
+    "Cool", 0x1);
+  modePairs.push_back(coolPair);
+
+  PIRStatePair *dehumidifyPair = new PIRStatePair(
+    "Dehumidify", 0x2);
+  modePairs.push_back(dehumidifyPair);
+
+  PIRStatePair *fanPair = new PIRStatePair(
+    "Fan", 0x3);
+  modePairs.push_back(fanPair);
+}
+
+
+void SamsungAC2::getAirCleanPairs(
+  PIRStatePairs &aircleanPairs) const
+{
+  resetPairs(aircleanPairs);
+
+  PIRStatePair *offPair = new PIRStatePair(
+    "Off", 0x0);
+  aircleanPairs.push_back(offPair);
+
+  PIRStatePair *onPair = new PIRStatePair(
+    "On", 0x4);
+  aircleanPairs.push_back(onPair);
+}
+
+
+void SamsungAC2::getPowerPairs(
+  PIRStatePairs &powerPairs) const
+{
+  resetPairs(powerPairs);
+
+  PIRStatePair *offPair = new PIRStatePair(
+    "Off", 0xE);
+  powerPairs.push_back(offPair);
+
+  PIRStatePair *onPair = new PIRStatePair(
+    "On", 0xF);
+  powerPairs.push_back(onPair);
+}
+
+
+void SamsungAC2::getTimerOptionPairs(
+  PIRStatePairs &timerOptionPairs) const
+{
+  resetPairs(timerOptionPairs);
+
+  PIRStatePair *cancelPair = new PIRStatePair(
+    "Cancel Timers", 0x0);
+  timerOptionPairs.push_back(cancelPair);
+
+  PIRStatePair *onPair = new PIRStatePair(
+    "Set On-Timer", 0x2);
+  timerOptionPairs.push_back(onPair);
+
+  PIRStatePair *offPair = new PIRStatePair(
+    "Set Off-Timer", 0x4);
+  timerOptionPairs.push_back(offPair);
 }
-*/
 
 
 SamsungDVBT1::SamsungDVBT1(
