@@ -548,6 +548,24 @@ bool MainWindow::startRepeating(
 }
 
 
+bool MainWindow::startRepeating(
+  PIRACStateInfo state,
+  PIRKeyName name)
+{
+  QMutexLocker locker(&commandIFMutex);
+  if (!commandInFlight)
+  {
+    commandInFlight = true;
+    emit buttonPressed(state, currentKeyset, name);
+    return true;
+  }
+  else
+  {
+    return false;
+  }
+}
+
+
 void MainWindow::stopRepeating()
 {
   QMutexLocker locker(&stopRepeatingMutex);
