@@ -12,6 +12,7 @@ class PIRSelectKeysetForm;
 class PIRSelectDeviceForm;
 class PIRFavoritesDialog;
 class PIRKeysetWidgetItem;
+class PIRACKeyset;
 
 #include <map>
 class PIRKeysetMetaData;
@@ -86,6 +87,9 @@ public:
     unsigned int dutyCycle,
     unsigned int keysetID);
 
+  const PIRACKeyset * getACKeyset(
+    unsigned int keysetID) const;
+
 private:
   void setupKeyset(
     PIRKeysetMetaData *keyset);
